CubeDim

Struct CubeDim 

pub struct CubeDim {
    pub x: u32,
    pub y: u32,
    pub z: u32,
}
The number of units across all 3 axis totalling to the number of working units in a cube.

Fields

x: u32

The number of units in the x axis.

y: u32

The number of units in the y axis.

z: u32

The number of units in the z axis.

Implementations



impl CubeDim

pub fn new<R>(client: &ComputeClient<R>, working_units: usize) -> CubeDim
where R: Runtime,

Creates a new CubeDim based on the maximum number of tasks that can be parellalized by units, in other words, by the maximum number of working units.

Notes

For complex problems, you probably want to have your own logic function to create the CubeDim, but for simpler problems such as elemwise-operation, this is a great default.

pub const fn new_single() -> CubeDim

Create a new cube dim with x = y = z = 1.

pub const fn new_1d(x: u32) -> CubeDim

Create a new cube dim with the given x, and y = z = 1.

pub const fn new_2d(x: u32, y: u32) -> CubeDim

Create a new cube dim with the given x and y, and z = 1.

pub const fn new_3d(x: u32, y: u32, z: u32) -> CubeDim

Create a new cube dim with the given x, y and z. This is equivalent to the new function.

pub const fn num_elems(&self) -> u32

Total numbers of units per cube

pub const fn can_contain(&self, other: CubeDim) -> bool

Whether this CubeDim can fully contain other